<?php

if (! defined('ABSPATH')) {
    exit;
}

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://ep.hr/
 * @since      1.0.0
 *
 * @package    Tecdoc_Woo
 * @subpackage Tecdoc_Woo/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Tecdoc_Woo
 * @subpackage Tecdoc_Woo/includes
 * @author     Elektronika Perhoč <support@ep.hr>
 */
class Tecdoc_Woo
{

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Tecdoc_Woo_Loader    $loader    Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $plugin_name    The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $version    The current version of the plugin.
     */
    protected $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct()
    {

        $this->plugin_name = 'tecdoc-woo';
        $this->version = '1.0.0';

        $this->load_dependencies();
        $this->set_locale();
        $this->define_public_hooks();
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Tecdoc_Woo_Loader. Orchestrates the hooks of the plugin.
     * - Tecdoc_Woo_i18n. Defines internationalization functionality.
     * - Tecdoc_Woo_Admin. Defines all hooks for the admin area.
     * - Tecdoc_Woo_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-tecdoc-woo-loader.php';

        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-tecdoc-woo-i18n.php';

        /**
         * The class responsible for TecDoc API actions
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-tecdoc-api.php';
        $tecdoc_api = new TecDoc_Api;

        /**
         * The class responsible for TecDoc Widget
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-widget.php';
        $widget = new tecdocWooWidget;

        /**
         * The class responsible for TecDoc Shortcode
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-shortcode.php';
        $shortcode = new tecdocWooShortcode;

        /**
         * WooCommerce overrides class
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-woocommerce-overrides.php';
        $wooOverrides = new wooCommerceOverrides;

        /**
         * WooCommerce taxonomy custom fields
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-term-custom-fields.php';
        $custom_fields = new Tecdoc_Term_Custom_Fields;

        /**
         * The class responsible for TecDoc Settings Page
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-settings-page.php';
        /**
         * The class responsible for defining all actions that occur in the admin area.
         */

         require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-tecdoc-endpoint.php';
         $wooEndpoint= new tecdocEndpoints;

        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-tecdoc-woo-public.php';

        $this->loader = new Tecdoc_Woo_Loader();
    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the Tecdoc_Woo_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale()
    {

        $plugin_i18n = new Tecdoc_Woo_i18n();

        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks()
    {

        $plugin_public = new Tecdoc_Woo_Public($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run()
    {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_plugin_name()
    {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Tecdoc_Woo_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader()
    {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version()
    {
        return $this->version;
    }
}
